@@ -1,6 +1,6 @@
 from builtins import exec as _builtin_exec, eval as _builtin_eval
 
-class Scope:
+class Scope(object):
     
     def __init__(self, settings={}):
         if not isinstance(settings, dict): raise TypeError("Arg 'settings' must be a dict object")
@@ -29,9 +29,38 @@ class Scope:
     def eval(self, s):
         return _builtin_eval(s, self.settings)
     
+    def keys(self):
+        return list(self.settings.keys())
+    
     def clear(self):
         self.settings.clear()
     
+    def __add__(self, scope):
+        keys = list(set(scope.keys()+self.keys()))
+        result = {}
+        for i in range(len(keys)):
+            result[keys[i]] = self.getitem(keys[i], scope.getitem(keys[i]))
+        s = Scope()
+        s.clear()
+        s.setitems(result)
+        return s
+    
+    def __sub__(self, scope):
+        keys = list(set(scope.keys())-set(self.keys()))
+        result = {}
+        for i in range(len(keys)):
+            result[keys[i]] = self.getitem(keys[i], scope.getitem(keys[i]))
+        s = Scope()
+        s.clear()
+        s.setitems(result)
+        return s
+    
+    def __radd__(self, scope):
+        return scope+self
+    
+    def __rsub__(self, scope):
+        return scope-self
+    
     def __bool__(self):
         return bool(self.settings)
     
